#ifndef _PY_MOD_score_H_
#define _PY_MOD_score_H_

void python_gc_score_module_init(void);

#endif
